@@ -524,6 +524,12 @@ def early():
     """
     return order() + _early_base
 
+class _cached_property(object):
+    def __init__(self, func):
+        self.func = func
+    def __get__(self, inst, class_):
+        return self.func(inst)
+
 _ext_re = re.compile('/(\w+)').search
 class _Handler:
 
@@ -555,7 +561,7 @@ class _Handler:
             order_ = order()
         self.bobo_order = order_
 
-    @property
+    @_cached_property
     def bobo_handle(self):
         func = original = self.bobo_original
         if self.params:
@@ -564,7 +570,7 @@ class _Handler:
         self.__dict__['bobo_handle'] = func
         return func
 
-    @property
+    @_cached_property
     def match(self):
         route_data = _compile_route(self.bobo_route, self.partial)
         methods = self.bobo_methods
@@ -940,8 +946,6 @@ def _compile_route(route, partial=False):
             if m is None:
                 return m
             path = path[len(m.group(0)):]
-            if path and not path.startswith('/'):
-                path = '/'+path
             return (dict(item for item in m.groupdict().iteritems()
                          if item[1] is not None),
                     path,
@@ -1283,5 +1287,6 @@ class MethodNotAllowed(Exception):
 class NotFound(Exception):
     """A resource cannot be found.
 
-    This exception can be raised by application code.
+    This exception can be conveniently raised by application
+    code. Bobo will catch it and generate a not-found response object.
     """
